%define         sversion        %(echo %version |sed -e 's#\\.##')

%define         major           5
%define         libname         %mklibname %{name} %{major}
%define         develname       %mklibname %name -d
%define         develnamestatic %mklibname %name -d -s

%define         subrel          1

Summary:        A library for accessing files in FITS format for C and Fortran
Name:           cfitsio
Version:        3.430
Release:        %mkrel 1
License:        BSD-like
Group:          System/Libraries

URL:            http://heasarc.gsfc.nasa.gov/docs/software/fitsio/
Source:         ftp://heasarc.gsfc.nasa.gov/software/fitsio/c/%{name}%{sversion}.tar.gz

#fix wrong version number in pc file (adds missing 0)
Patch1:         cfitsio-3.350-pkgconfig.patch
#fix security issues mga#24586 from fedora
Patch2:         cfitsio-backport344.patch

BuildRequires:  sed
BuildRequires:  grep
BuildRequires:  bison
BuildRequires:  flex
BuildRequires:  gcc-gfortran
%ifnarch %arm
BuildRequires:  quadmath-devel
%endif
BuildRequires:  pkgconfig(pkg-config)


%description
Cfitsio is a library of C and Fortran subroutines for reading and
writing data files in FITS (Flexible Image Transport System) data
format.  Cfitsio simplifies the task of writing software that deals
with FITS files by providing an easy to use set of high-level routines
that insulate the programmer from the internal complexities of the
FITS file format.  At the same time, cfitsio provides many advanced
features that have made it the most widely used FITS file programming
interface in the astronomical community.


%package -n %{libname}
License:        BSD-like
Summary:        A library for accessing files in FITS format for C and Fortran
Group:          System/Libraries
Provides:       lib%{name} = %{version}-%{release}

%description -n %{libname}
This package contains the shared library required by programs that use
the cfitsio library.



%package -n %{develname}
License:        BSD-like
Summary:        Headers, libraries, & docs for the cfitsio library
Group:          System/Libraries
Provides:       fitsio-devel = %{version}-%{release}
Provides:       %{name}-devel = %{version}-%{release}
Provides:       lib%{name}-devel = %{version}-%{release}
Requires:       %{libname} = %{version}-%{release}

%description -n %{develname}
This package contains the headers required for compiling software that uses
the cfitsio library.



%package -n %{develnamestatic}
License:        BSD-like
Summary:        Static development file for the cfitsio library
Group:          System/Libraries
Requires:       %{develname} = %{version}-%{release}
Requires:       %{libname} = %{version}-%{release}
Requires:       pkgconfig
Provides:       lib%{name}-static-devel = %{version}-%{release}

%description -n %{develnamestatic}
This package contains the static files required for compiling software that uses
the cfitsio library.


%prep
%setup -q -n %{name}
%autopatch -p1


%build
autoreconf --force --install

# (cjw) ssse3 is not standard on x86-64 so it cannot be enabled at compile time
%configure2_5x \
               %ifarch x86_64
               --enable-sse2 \
               %endif
               --enable-reentrant

%make shared
%make fpack
%make funpack
%make fitscopy
%make imcopy


%check
make testprog
LD_LIBRARY_PATH=. ./testprog > testprog.lis
cmp -s testprog.lis testprog.out
cmp -s testprog.fit testprog.std



%install

%makeinstall_std
%__install -D -m755 fpack %{buildroot}%{_bindir}/fpack
%__install -D -m755 funpack %{buildroot}%{_bindir}/funpack
%__install -D -m755 fitscopy %{buildroot}%{_bindir}/fitscopy
%__install -D -m755 imcopy %{buildroot}%{_bindir}/imcopy




%files
%{_bindir}/*


%files -n %{libname}
%doc README
%{_libdir}/*.so.%{major}{,.*}


%files -n %{develname}
%{_libdir}/*.so
%{_includedir}/*
%{_libdir}/pkgconfig/*


%files -n %{develnamestatic}
%{_libdir}/*.a





%changelog
* Thu Mar 28 2019 eatdirt <eatdirt> 3.430-1.1.mga6
+ Revision: 1380902
- Fix security issues #24586
- Upgrade to bugfix release 3.430 (#mga22855)

* Wed Dec 14 2016 eatdirt <eatdirt> 3.410-1.mga6
+ Revision: 1075024
- Upgrade to bux fix release 3.410

* Tue Nov 22 2016 eatdirt <eatdirt> 3.400-1.mga6
+ Revision: 1068752
- Upgrade to cfitsio 3.400

* Wed Mar 09 2016 wally <wally> 3.380-3.mga6
+ Revision: 988522
- do not obsolete old lib as it defeats the purpose of libification

* Wed Mar 09 2016 eatdirt <eatdirt> 3.380-2.mga6
+ Revision: 988514
- Fix missing provides and obsoletes

* Wed Mar 09 2016 eatdirt <eatdirt> 3.380-1.mga6
+ Revision: 988476
- Upgrade to version 3.380
+ umeabot <umeabot>
- Mageia 6 Mass Rebuild

* Thu Nov 19 2015 neoclust <neoclust> 3.370-5.mga6
+ Revision: 904249
- quadmath-devel is not available on ARM

* Wed Oct 15 2014 umeabot <umeabot> 3.370-4.mga5
+ Revision: 749367
- Second Mageia 5 Mass Rebuild

* Thu Sep 18 2014 umeabot <umeabot> 3.370-3.mga5
+ Revision: 693588
- Rebuild to fix library dependencies

* Tue Sep 16 2014 umeabot <umeabot> 3.370-2.mga5
+ Revision: 678353
- Mageia 5 Mass Rebuild

* Wed Jul 02 2014 eatdirt <eatdirt> 3.370-1.mga5
+ Revision: 642188
- Upgrade to version 3.370

* Sat Mar 01 2014 wally <wally> 3.360-2.mga5
+ Revision: 598365
- drop unneeded require
- don't obsolete libs with old major
- remove unneeded conflicts

* Thu Feb 27 2014 eatdirt <eatdirt> 3.360-1.mga5
+ Revision: 597676
- Upgrade to version 3.360

* Sat Oct 19 2013 umeabot <umeabot> 3.350-4.mga4
+ Revision: 530172
- Mageia 4 Mass Rebuild

* Fri Jul 19 2013 eatdirt <eatdirt> 3.350-3.mga4
+ Revision: 456378
- Fix wrong obsoleted libname

* Tue Jul 16 2013 eatdirt <eatdirt> 3.350-2.mga4
+ Revision: 455075
- Fix missing obsolete

* Tue Jul 16 2013 eatdirt <eatdirt> 3.350-1.mga4
+ Revision: 454913
- Upgrade to 3.350, cleaning specfile

* Fri Jun 07 2013 eatdirt <eatdirt> 3.340-2.mga4
+ Revision: 438685
- Fixing broken deps (missing soname compilation flags)

* Thu Jun 06 2013 eatdirt <eatdirt> 3.340-1.mga4
+ Revision: 438546
- Upgrade to version 3.340

* Fri Jan 11 2013 cjw <cjw> 3.310-3.mga3
+ Revision: 348386
- do not enable ssse3 on x86-64 since not all cpus support it

* Fri Jan 11 2013 umeabot <umeabot> 3.310-2.mga3
+ Revision: 347575
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Wed Aug 22 2012 eatdirt <eatdirt> 3.310-1.mga3
+ Revision: 283177
- Upgrade to version 3.310

* Tue Jul 10 2012 eatdirt <eatdirt> 3.300-2.mga3
+ Revision: 269251
- Fixes missing linker option, cleaning specfile

* Mon Jul 09 2012 eatdirt <eatdirt> 3.300-1.mga3
+ Revision: 269112
- Upgrade to version 3.300, cleaning specfile

* Thu Dec 15 2011 fwang <fwang> 3.290-1.mga2
+ Revision: 181680
- update patch
- new version 3.290

* Tue Jun 28 2011 fwang <fwang> 3.280-1.mga2
+ Revision: 115161
- new version 3.280

* Sat Jan 22 2011 ahmad <ahmad> 3.250-2.mga1
+ Revision: 33112
- drop old/unneeded scriptlets
- imported package cfitsio

